Learn R Programming

rbundler (version 0.3.4)

find_available_versions: Retrieves a list of available versions for a package.

Description

Retrieves a list of available versions for a package.

Usage

find_available_versions(package,
    repos = getOption("repos"),
    type = getOption("pkgType"))

Arguments

package
the package name
repos
character vector, the base URL(s) of the repositories to use, e.g., the URL of a CRAN mirror such as "http://cran.us.r-project.org".

Can be NULL to install from local files (with extension .tar.gz for source

type
character, indicating the type of package to download and install.

Possible values are "source", "mac.binary.leopard" and "win.binary": the binary types can be listed and downloaded but not installed on ot